@@ -1,6 +1,6 @@
-from sklearn.datasets import load_boston
+from sklearn.datasets import load_diabetes
 from sklearn.model_selection import KFold
-from photonai.base import Hyperpipe, PipelineElement, CallbackElement
+from photonai import Hyperpipe, PipelineElement, CallbackElement
 
 
 # DEFINE CALLBACK ELEMENT
@@ -33,5 +33,5 @@ my_pipe += CallbackElement("monitor", my_monitor)
 
 my_pipe += PipelineElement('RandomForestRegressor', hyperparameters={'n_estimators': [10, 100]})
 
-X, y = load_boston(return_X_y=True)
+X, y = load_diabetes(return_X_y=True)
 my_pipe.fit(X, y)
