@@ -1,7 +1,6 @@
 from sklearn.datasets import load_breast_cancer
 from sklearn.model_selection import KFold
-from photonai.base import Hyperpipe, PipelineElement
-from photonai.optimization import FloatRange
+from photonai import Hyperpipe, PipelineElement, FloatRange
 
 my_pipe = Hyperpipe('basic_forest_pipe',
                     inner_cv=KFold(n_splits=2),
