@@ -1,8 +1,7 @@
 from sklearn.datasets import load_iris
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement
-from photonai.optimization import FloatRange, Categorical
+from photonai import Hyperpipe, PipelineElement, FloatRange, Categorical
 
 # loading the iris dataset
 X, y = load_iris(return_X_y=True)
