@@ -1,8 +1,7 @@
 from sklearn.datasets import load_breast_cancer
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement, Preprocessing
-from photonai.optimization import FloatRange, Categorical, IntegerRange
+from photonai import Hyperpipe, PipelineElement, Preprocessing, FloatRange, Categorical, IntegerRange
 
 # WE USE THE BREAST CANCER SET FROM SKLEARN
 X, y = load_breast_cancer(return_X_y=True)
