@@ -1,8 +1,7 @@
 from sklearn.datasets import load_breast_cancer
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement
-from photonai.optimization import FloatRange, Categorical, IntegerRange
+from photonai import Hyperpipe, PipelineElement, FloatRange, Categorical, IntegerRange
 
 my_pipe = Hyperpipe('basic_svm_pipe',
                     inner_cv=KFold(n_splits=5),
@@ -17,6 +16,7 @@ my_pipe.add(PipelineElement('StandardScaler'))
 
 my_pipe += PipelineElement('PCA',
                            hyperparameters={'n_components': IntegerRange(10, 30)},
+                           n_components=10,
                            test_disabled=True)
 
 my_pipe += PipelineElement('SVC',
