@@ -1,10 +1,9 @@
-from sklearn.datasets import load_boston
+from sklearn.datasets import load_diabetes
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement, Switch
-from photonai.optimization import IntegerRange
+from photonai import Hyperpipe, PipelineElement, Switch, IntegerRange
 
-X, y = load_boston(return_X_y=True)
+X, y = load_diabetes(return_X_y=True)
 
 my_pipe = Hyperpipe('feature_selection',
                     optimizer='grid_search',
