@@ -1,8 +1,7 @@
 from sklearn.datasets import load_breast_cancer
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement, Stack
-from photonai.optimization import FloatRange, IntegerRange
+from photonai import Hyperpipe, PipelineElement, Stack, FloatRange, IntegerRange
 
 X, y = load_breast_cancer(return_X_y=True)
 
