@@ -1,8 +1,7 @@
 from sklearn.datasets import load_digits
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement
-from photonai.optimization import Categorical
+from photonai import Hyperpipe, PipelineElement, Categorical
 
 # WE USE THE BREAST CANCER SET FROM SKLEARN
 X, y = load_digits(n_class=5, return_X_y=True)
