@@ -1,11 +1,9 @@
-from sklearn.datasets import load_boston
+from sklearn.datasets import load_diabetes
 from sklearn.model_selection import KFold, ShuffleSplit
 
-from photonai.base import Hyperpipe, PipelineElement
-from photonai.optimization import FloatRange, Categorical
+from photonai import Hyperpipe, PipelineElement, FloatRange, Categorical
 
-# WE USE THE BOSTON HOUSING DATA FROM SKLEARN
-X, y = load_boston(return_X_y=True)
+X, y = load_diabetes(return_X_y=True)
 
 # DESIGN YOUR PIPELINE
 my_pipe = Hyperpipe('skopt_example',
