@@ -3,8 +3,7 @@ import pandas as pd
 import numpy as np
 from sklearn.model_selection import StratifiedShuffleSplit
 
-from photonai.base import Hyperpipe, PipelineElement
-from photonai.optimization import FloatRange
+from photonai import Hyperpipe, PipelineElement, FloatRange
 from sklearn.datasets import fetch_openml
 
 # blood-transfusion-service-center
