@@ -6,7 +6,7 @@ import sys
 from glob import glob
 
 import numpy as np
-from sklearn.datasets import load_breast_cancer, load_boston
+from sklearn.datasets import load_breast_cancer, load_diabetes
 from shutil import copyfile
 
 from photonai.photonlogger.logger import logger
@@ -68,8 +68,12 @@ class PhotonRegistry:
 
         # update list with available sub_elements
         self._list_available_modules()
-        PhotonRegistry.CUSTOM_ELEMENTS_FOLDER = custom_elements_folder
-        self._load_custom_folder(custom_elements_folder)
+        if PhotonRegistry.CUSTOM_ELEMENTS_FOLDER is not None and custom_elements_folder is None:
+            logger.info(f"Keeping custom elements folder {PhotonRegistry.CUSTOM_ELEMENTS_FOLDER}")
+        else:
+            PhotonRegistry.CUSTOM_ELEMENTS_FOLDER = custom_elements_folder
+
+        self._load_custom_folder(PhotonRegistry.CUSTOM_ELEMENTS_FOLDER)
 
         if len(PhotonRegistry.ELEMENT_DICTIONARY) == 0 or \
                 PhotonRegistry.ELEMENT_DICTIONARY == PhotonRegistry.CUSTOM_ELEMENTS:
@@ -281,7 +285,7 @@ class PhotonRegistry:
             if hasattr(custom_element, '_estimator_type'):
                 est_type = getattr(custom_element, '_estimator_type')
                 if est_type == "regressor":
-                    X, y = load_boston(return_X_y=True)
+                    X, y = load_diabetes(return_X_y=True)
                 elif est_type == "classifier":
                     X, y = load_breast_cancer(return_X_y=True)
                 else:
@@ -292,7 +296,7 @@ class PhotonRegistry:
                                           "Consider inheritance from ClassifierMixin or RegressorMixin or set "
                                           "_estimator_type manually.")
         else:
-            X, y = load_boston(return_X_y=True)
+            X, y = load_diabetes(return_X_y=True)
 
         # try and test functionality
         kwargs = {'covariates': np.random.randn(len(y))}
