@@ -14,7 +14,7 @@ class BaseModelWrapperTest(unittest.TestCase):
 
     def test_methods_available(self):
         if hasattr(self.model_wrapper, '_estimator_type'):
-            if self.model_wrapper._estimator_type in ['classifiern', 'regressor']:
+            if self.model_wrapper._estimator_type in ['classifier', 'regressor']:
                 methods = ['fit', 'predict', 'get_params', 'set_params']
                 for method in methods:
                     self.assertTrue(
