@@ -1,7 +1,7 @@
 import unittest
 import numpy as np
 
-from sklearn.utils.testing import assert_array_equal
+from numpy.testing import assert_array_equal
 from photonai.modelwrapper.label_encoder import LabelEncoder
 
 
